# report

a small text editor

![](https://raw.githubusercontent.com/wdbm/report/master/report.png)

# setup

```Bash
sudo apt install python3-pyqt5
pip install wirereport
```

# run

```Python
report
```
